foowise
--------

Infomorphic channels ([Barwise and Seligman, 1997][blue book]) rigorously formalize what it means for data to carry meaning across time, space, and subjectivity.

The purpose this repository to is to mechanize the underlying theory, and to demonstrate a few interesting applications.

(2018.07.04)

-----

See Also:

Barwise and Seligman's original exposition:

https://books.google.com/books?id=Mawadg55eg4C&printsec=front_cover&hl=en

A glossary of terms:

https://github.com/ben-schulz/foowise/blob/master/docs/glossary.md
